@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ox-spectacle" "2.0.1"
+(define-package "ox-spectacle" "20250218.1032"
   "Spectacle.js Presentation Back-End for Org Export Engine."
   '((emacs "28.1")
     (org   "8.3"))
